@@ -1,8 +1,10 @@
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
+
 /* Metacity visual bell */
 
 /* 
  * Copyright (C) 2002 Sun Microsystems Inc.
- * Copyright (C) 2005 Elijah Newren
+ * Copyright (C) 2005, 2006 Elijah Newren
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -252,5 +254,5 @@ void
 meta_bell_notify_frame_destroy (MetaFrame *frame)
 {
   if (frame->is_flashing) 
-    g_idle_remove_by_data (frame);
+    g_source_remove_by_funcs_user_data (&g_timeout_funcs, frame);
 }
